@@ -1,22 +1,20 @@
-from .. import engine
-from . import Block
+from .. import Interpreter, adapter
+from ..interface import Block
 from typing import Optional
 import random
 
 class RandomBlock(Block):
-    def will_accept(self, ctx : engine.Interpreter.Context) -> bool:
+    def will_accept(self, ctx : Interpreter.Context) -> bool:
         dec = ctx.verb.declaration.lower()
         return any([dec == "random", dec == "#", dec =="rand"])
 
-    def process(self, ctx : engine.Interpreter.Context) -> Optional[str]:
+    def process(self, ctx : Interpreter.Context) -> Optional[str]:
         spl = []
         if "~" in ctx.verb.payload:
             spl = ctx.verb.payload.split("~")
         else:
             spl = ctx.verb.payload.split(",")
-        if ctx.verb.parameter is not None:
-            random.seed(ctx.verb.parameter)
+        random.seed(ctx.verb.parameter)
 
         result = random.choice(spl)
-        ctx.handled = True
-        return result
+        return result
\ No newline at end of file
